*****************************************
The sherpa.optmethods.optoptimagic module
*****************************************

.. currentmodule:: sherpa.optmethods.optoptimagic

.. automodule:: sherpa.optmethods.optoptimagic
   
  .. rubric:: Classes
              
  .. autosummary::
     :toctree: api

     Optimagic

Class Inheritance Diagram
=========================

.. inheritance-diagram::  Optimagic
   :parts: 1